Citing
======

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3551990.svg
    :target: https://doi.org/10.5281/zenodo.3551990
    :alt: Zenodo

Please cite **taurenmd** in your publications and research/work enviroment. This project is indexed at `Zenodo <https://doi.org/10.5281/zenodo.3551990>`_ and you can cite it in two different ways:

#. refering to the whole project:::
    
    TaurenMD. João M.C. Teixeira. joaomcteixeira/taurenmd: Zenodo. http://doi.org/10.5281/zenodo.3551990

#. refering the exact verion used, for example:::

    TaurenMD. João M.C. Teixeira. (2019, December 23). joaomcteixeira/taurenmd: v0.7.0 (Version v0.7.0). Zenodo. http://doi.org/10.5281/zenodo.3591907

citing is one of the best ways to support this project.

:IMPORTANT: When using and citing :code:`taurenmd`, you **SHOULD by all means** cite the Molecular Dynamics (MD) analysis libraries upon which :code:`taurenmd` wraps, these are the **tauremd** software dependencies. A list of all taurenmd dependencies can be found :ref:`here <dependencies>`. Taurenmd uses different libraries depending on the :ref:`client interface <Usage>` used, after each command execution a :code:`.citing` file is created indicated the *additional* projects you should also cite; you should refer to that project webpage and read through their citing instructions.
